#!/apps/PYTHON/2.7.3/bin/python
# -*- coding:UTF-8 -*- 
#
###############################
# This script generates mask of the regions of a selected version of mesh.mask of NEMO
# History : Matthieu Chevallier - Initial version -       2015
#           Rubén Cruz García - Generic and adapted version to the CPG - July  2016
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

import numpy as N
from netCDF4 import Dataset as nc

lstversion = ('Ec2.3_O1L42','Ec3.0_O1L46', 'N3.2_O1L42', 'N3.3_O1L46', 'N3.6_O1L75')  # Version of the mask that you want to create
# Options = Ec2.3_O1L42, Ec3.0_O1L46, N3.2_O1L42, N3.3_O1L46, N3.6_O1L75, Ec3.0_O25L46 

for version in lstversion:

    option_grid = 't'
    fmask = nc("/esnas/autosubmit/con_files/mesh_mask_nemo.%s.nc" % version)
    longitude = fmask.variables['nav_lon'][:]
    latitude = fmask.variables['nav_lat'][:]
    tmask = fmask.variables['tmask'][0, :, :, :]

    mask_v = tmask[0, :, :]

    dom_dict = dict()
    dom_arct = dict()

    # GENERAL SEA AREAS
    #
    # Global ocean
    dom_dict['Global_Ocean'] = mask_v
    #
    # North Hemisphere
    nhemisph = N.where(latitude > 0, mask_v, 0)
    dom_dict['Northern_Hemisphere'] = nhemisph
    #
    # South Hemisphere
    shemisph = N.where(latitude < 0, mask_v, 0)
    dom_dict['Southern_Hemisphere'] = shemisph
    #
    # Antarctic Ocean
    antarctx = N.where(latitude < -40., mask_v, 0)
    dom_dict['Antarctic_Ocean'] = antarctx
    #
    # Mediterranean Sea
    bool_medit_1 = N.logical_and(N.logical_and(latitude > 30, latitude < 40),
                                 N.logical_and(longitude > -5, longitude < 0))
    bool_medit_2 = N.logical_and(N.logical_and(latitude > 30, latitude < 46),
                                 N.logical_and(longitude > 0, longitude < 28))
    bool_medit_3 = N.logical_and(N.logical_and(latitude > 30, latitude < 40),
                                 N.logical_and(longitude > 28, longitude < 40))
    bool_medit = N.logical_or(N.logical_or(bool_medit_1, bool_medit_2), bool_medit_3)
    mediterr = N.where(bool_medit, mask_v, 0)
    dom_dict['Mediterranean_Sea'] = mediterr
    #
    # North Atlantic
    bool_natl_1 = N.logical_and(N.logical_and(latitude > 32, latitude < 73),
                                N.logical_and(longitude > -95, longitude < 26))
    bool_natl_2 = N.logical_and(N.logical_and(latitude > 73, latitude < 75),
                                N.logical_and(longitude > -30, longitude < 24))
    bool_natl_3 = N.logical_and(N.logical_and(latitude > 75, latitude < 77),
                                N.logical_and(longitude > -30, longitude < 22))
    bool_natl_4 = N.logical_and(N.logical_and(latitude > 77, latitude < 79),
                                N.logical_and(longitude > -30, longitude < 18))
    # Fram Strait
    bool_natl_5 = N.logical_and(N.logical_and(latitude > 79, latitude < 81),
                                N.logical_and(longitude > -30, longitude < 17))
    #
    bool_natl_6 = N.logical_and(N.logical_and(latitude > 73, latitude <= 82),
                                N.logical_and(longitude > -83, longitude < -35))
    bool_natl = N.logical_or(N.logical_or(bool_natl_1, bool_natl_2), bool_natl_3)
    bool_natl = N.logical_or(bool_natl, bool_natl_4)
    bool_natl = N.logical_or(bool_natl, bool_natl_5)
    bool_natl = N.logical_or(bool_natl, bool_natl_6)
    bool_natl = N.logical_and(bool_natl, N.logical_not(bool_medit))
    northatl = N.where(bool_natl, mask_v, 0)
    dom_dict['North_Atlantic_Ocean'] = northatl
    #
    # Greenland Sea
    bool_green_1 = N.logical_and(N.logical_and(latitude > 76, latitude < 81),
                                 N.logical_and(longitude > -30, longitude < 17))
    bool_green_2 = N.logical_and(N.logical_and(latitude > 75, latitude < 76),
                                 N.logical_and(longitude > -30, longitude < 12))
    bool_green_3 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                 N.logical_and(longitude > -30, longitude < 9))
    bool_green_4 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                 N.logical_and(longitude > -30, longitude < 4))
    bool_green_5 = N.logical_and(N.logical_and(latitude > 72, latitude < 73),
                                 N.logical_and(longitude > -30, longitude < 0))
    bool_green_6 = N.logical_and(N.logical_and(latitude > 71, latitude < 72),
                                 N.logical_and(longitude > -30, longitude < -3))
    bool_green_7 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                 N.logical_and(longitude > -30, longitude < -8))
    bool_green = bool_green_1
    for i in range(2, 8):
        exec ('bool_green = N.logical_or(bool_green,bool_green_' + str(i) + ')')
    #
    greenlan = N.where(bool_green, mask_v, 0)
    dom_dict['Greenland_Sea'] = greenlan
    #
    # Icelandic Sea: N->S, Jan Mayen is SE corner
    bool_icel_1 = N.logical_and(N.logical_and(latitude > 69, latitude < 70),
                                N.logical_and(longitude > -29, longitude < -9))
    bool_icel_2 = N.logical_and(N.logical_and(latitude > 68, latitude < 69),
                                N.logical_and(longitude > -28, longitude < -10))
    bool_icel_3 = N.logical_and(N.logical_and(latitude > 67, latitude < 68),
                                N.logical_and(longitude > -25, longitude < -11))
    bool_icel_4 = N.logical_and(N.logical_and(latitude > 66, latitude < 67),
                                N.logical_and(longitude > -23, longitude < -12))
    bool_icel_5 = N.logical_and(N.logical_and(latitude > 65, latitude < 66),
                                N.logical_and(longitude > -20, longitude < -13))
    bool_icel = bool_icel_1
    for i in range(2, 6):
        exec ('bool_icel=N.logical_or(bool_icel,bool_icel_' + str(i) + ')')

    icelands = N.where(bool_icel, mask_v, 0)
    dom_dict['Icelandic_Sea'] = icelands
    #
    # Norwegian Sea: N->S, Bjornoya is E corner, then North Cape
    bool_norw_1 = N.logical_and(N.logical_and(latitude > 75, latitude < 76),
                                N.logical_and(longitude > 12, longitude < 17))
    bool_norw_2 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                N.logical_and(longitude > 9, longitude < 18))
    bool_norw_3 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                N.logical_and(longitude > 4, longitude < 19))
    # I reached Bjornoya
    bool_norw_4 = N.logical_and(N.logical_and(latitude > 72, latitude < 73),
                                N.logical_and(longitude > 0, longitude < 21))
    bool_norw_5 = N.logical_and(N.logical_and(latitude > 71, latitude < 72),
                                N.logical_and(longitude > -3, longitude < 23))
    bool_norw_6 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                N.logical_and(longitude > -8, longitude < 25))
    # I reached North Cape
    bool_norw_7 = N.logical_and(N.logical_and(latitude > 66, latitude < 70),
                                N.logical_and(longitude > -13, longitude < 25))
    bool_norw_7 = N.logical_and(bool_norw_7, N.logical_not(bool_icel))
    bool_norw_8 = N.logical_and(N.logical_and(latitude > 62, latitude < 66),
                                N.logical_and(longitude > -6, longitude < 15))
    bool_norw_9 = N.logical_and(N.logical_and(latitude > 61, latitude < 62),
                                N.logical_and(longitude > 0, longitude < 15))
    bool_norw_10 = N.logical_and(N.logical_and(latitude > 63, latitude < 64),
                                 N.logical_and(longitude > -8, longitude < -6))
    bool_norw_11 = N.logical_and(N.logical_and(latitude > 64, latitude < 65),
                                 N.logical_and(longitude > -10, longitude < -6))
    bool_norw_12 = N.logical_and(N.logical_and(latitude > 65, latitude < 66),
                                 N.logical_and(longitude > -13, longitude < -6))
    bool_norw = bool_norw_1
    for i in range(2, 13):
        exec ('bool_norw=N.logical_or(bool_norw,bool_norw_' + str(i) + ')')

    norskhav = N.where(bool_norw, mask_v, 0)
    dom_dict['Norwegian_Sea'] = norskhav
    #
    # GIN seas: simple one!!!
    bool_gins = N.logical_or(N.logical_or(bool_green, bool_icel), bool_norw)
    ginseasx = N.where(bool_gins, mask_v, 0)
    dom_dict['Nordic_Seas'] = ginseasx
    dom_dict['Grnland'] = ginseasx
    dom_arct['GINSEASX'] = ginseasx
    #
    #
    # Barents Sea (including White Sea)
    # E limit of Greenland Sea -> FJL -> Cape Zhelanya
    bool_barnts_1 = N.logical_and(N.logical_and(latitude > 76, latitude < 80),
                                  N.logical_and(longitude > 17, longitude < 65))
    # E limit of Norwegian Sea -> Novaya Zemlya
    bool_barnts_2 = N.logical_and(N.logical_and(latitude > 75, latitude < 76),
                                  N.logical_and(longitude > 17, longitude < 62))
    bool_barnts_3 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                  N.logical_and(longitude > 18, longitude < 59))
    bool_barnts_4 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                  N.logical_and(longitude > 19, longitude < 58))
    bool_barnts_5 = N.logical_and(N.logical_and(latitude > 72, latitude < 73),
                                  N.logical_and(longitude > 21, longitude < 56))
    bool_barnts_6 = N.logical_and(N.logical_and(latitude > 71, latitude < 72),
                                  N.logical_and(longitude > 23, longitude < 56))
    bool_barnts_7 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                  N.logical_and(longitude > 25, longitude < 57))
    # I reached North Cape and Kara Gate Strait
    bool_barnts_8 = N.logical_and(N.logical_and(latitude > 66, latitude < 70),
                                  N.logical_and(longitude > 25, longitude < 60))
    # I fill the White Sea
    bool_barnts_9 = N.logical_and(N.logical_and(latitude > 63, latitude < 66),
                                  N.logical_and(longitude > 30, longitude < 45))
    bool_barnts = bool_barnts_1
    for i in range(2, 10):
        exec ('bool_barnts=N.logical_or(bool_barnts,bool_barnts_' + str(i) + ')')

    barentsx = N.where(bool_barnts, mask_v, 0)
    dom_dict['Barents_Sea'] = barentsx
    dom_arct['BARENTSX'] = barentsx
    #
    #
    # Kara Sea
    # Northern part: FJL - Svernya Zemlya - Cape Chelyuskin - Cape Zhelanya
    bool_kara_1 = N.logical_and(N.logical_and(latitude > 79, latitude < 80),
                                N.logical_and(longitude > 65, longitude < 96))
    bool_kara_2 = N.logical_and(N.logical_and(latitude > 76, latitude <= 79),
                                N.logical_and(longitude > 65, longitude < 105))
    # I fill southwestern part of the sea
    bool_kara_3 = N.logical_and(N.logical_and(latitude > 75, latitude < 76),
                                N.logical_and(longitude > 62, longitude < 100))
    bool_kara_4 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                N.logical_and(longitude > 59, longitude < 100))
    bool_kara_5 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                N.logical_and(longitude > 58, longitude < 100))
    bool_kara_6 = N.logical_and(N.logical_and(latitude > 71, latitude < 73),
                                N.logical_and(longitude > 56, longitude < 100))
    bool_kara_7 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                N.logical_and(longitude > 57, longitude < 100))
    # I reached Kara Gate Strait and Yamal coast
    bool_kara_8 = N.logical_and(N.logical_and(latitude > 66, latitude < 70),
                                N.logical_and(longitude > 60, longitude < 90))
    bool_kara = bool_kara_1
    for i in range(2, 9):
        exec ('bool_kara=N.logical_or(bool_kara,bool_kara_' + str(i) + ')')

    karaxxxx = N.where(bool_kara, mask_v, 0)
    dom_dict['Kara_Sea'] = karaxxxx
    dom_arct['KARAXXXX'] = karaxxxx
    #
    #
    # Laptev Sea
    #
    bool_lapt_1 = N.logical_and(N.logical_and(latitude > 80, latitude < 81),
                                N.logical_and(longitude > 96, longitude < 102))
    bool_lapt_2 = N.logical_and(N.logical_and(latitude > 79, latitude < 80),
                                N.logical_and(longitude > 100, longitude < 111))
    bool_lapt_3 = N.logical_and(N.logical_and(latitude > 78, latitude < 79),
                                N.logical_and(longitude > 105, longitude < 120))
    bool_lapt_4 = N.logical_and(N.logical_and(latitude > 77, latitude < 78),
                                N.logical_and(longitude > 105, longitude < 129))
    bool_lapt_5 = N.logical_and(N.logical_and(latitude > 76, latitude < 77),
                                N.logical_and(longitude > 100, longitude < 138))
    # I reached Novaya Zemlya Archipelago: now cross Laptev Strait
    bool_lapt_6 = N.logical_and(N.logical_and(latitude > 70, latitude < 76),
                                N.logical_and(longitude > 105, longitude < 140))
    bool_lapt = bool_lapt_1
    for i in range(2, 7):
        exec ('bool_lapt=N.logical_or(bool_lapt,bool_lapt_' + str(i) + ')')

    laptevxx = N.where(bool_lapt, mask_v, 0)
    idx_laptev = N.where((karaxxxx == 1) & (laptevxx == 1))
    laptevxx[idx_laptev] = 0

    # laptevxx = N.where(bool_lapt, mask_v, 0)
    dom_dict['Laptev_Sea'] = laptevxx
    dom_arct['LAPTEVXX'] = laptevxx
    #
    #
    # East Siberian Sea
    #
    bool_easib_1 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                 N.logical_and(longitude > 140, longitude < 146))
    bool_easib_2 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                 N.logical_and(longitude > 140, longitude < 154))
    bool_easib_3 = N.logical_and(N.logical_and(latitude > 72, latitude < 73),
                                 N.logical_and(longitude > 140, longitude < 162))
    bool_easib_4 = N.logical_and(N.logical_and(latitude > 71, latitude < 72),
                                 N.logical_and(longitude > 140, longitude < 170))
    bool_easib_5 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                 N.logical_and(longitude > 140, longitude < 179))
    # I reached Wrangel Island
    bool_easib_6 = N.logical_and(N.logical_and(latitude > 69, latitude < 70),
                                 N.logical_and(longitude > 140, longitude < 178))
    bool_easib_7 = N.logical_and(N.logical_and(latitude > 68, latitude < 69),
                                 N.logical_and(longitude > 140, longitude < 178))
    bool_easib = bool_easib_1
    for i in range(2, 8):
        exec ('bool_easib=N.logical_or(bool_easib,bool_easib_' + str(i) + ')')

    eastsibe = N.where(bool_easib, mask_v, 0)
    dom_dict['East_Siberian_Sea'] = eastsibe
    dom_arct['EASTSIBE'] = eastsibe
    #
    #
    # Chukchi Sea
    #
    bool_chuk_1 = N.logical_and(N.logical_and(latitude > 66, latitude < 71), longitude < -156)
    bool_chuk_2 = N.logical_and(N.logical_and(latitude > 66, latitude < 71), longitude > 179)
    bool_chuk_3 = N.logical_and(N.logical_and(latitude > 69, latitude < 70), longitude > 178)
    bool_chuk = N.logical_or(bool_chuk_1, bool_chuk_2)
    bool_chuk = N.logical_or(bool_chuk, bool_chuk_3)
    chukchis = N.where(bool_chuk, mask_v, 0)
    dom_dict['Chukchi_Sea'] = chukchis
    dom_arct['CHUKCHIS'] = chukchis
    #
    #
    # Okhotsk Sea
    # First step: Kuriles archipelago and Sakhaline Island
    bool_okhot_1 = N.logical_and(N.logical_and(latitude > 43, latitude < 44),
                                 N.logical_and(longitude > 141, longitude < 146))
    bool_okhot_2 = N.logical_and(N.logical_and(latitude > 44, latitude < 45),
                                 N.logical_and(longitude > 141, longitude < 147))
    bool_okhot_3 = N.logical_and(N.logical_and(latitude > 45, latitude < 46),
                                 N.logical_and(longitude > 141, longitude < 150))
    bool_okhot_4 = N.logical_and(N.logical_and(latitude > 46, latitude < 47),
                                 N.logical_and(longitude > 141, longitude < 150))
    bool_okhot_5 = N.logical_and(N.logical_and(latitude > 47, latitude < 48),
                                 N.logical_and(longitude > 141, longitude < 151))
    bool_okhot_6 = N.logical_and(N.logical_and(latitude > 48, latitude < 49),
                                 N.logical_and(longitude > 141, longitude < 152.5))
    bool_okhot_7 = N.logical_and(N.logical_and(latitude > 49, latitude < 50),
                                 N.logical_and(longitude > 141, longitude < 154))
    bool_okhot_8 = N.logical_and(N.logical_and(latitude > 50, latitude < 51),
                                 N.logical_and(longitude > 140, longitude < 155.5))
    bool_okhot_9 = N.logical_and(N.logical_and(latitude > 51, latitude < 52),
                                 N.logical_and(longitude > 139, longitude < 157))
    # I am at the southernmost point of Kamtchatka
    bool_okhot_10 = N.logical_and(N.logical_and(latitude > 52, latitude < 63),
                                  N.logical_and(longitude > 135, longitude < 157))
    bool_okhot_11 = N.logical_and(N.logical_and(latitude > 58, latitude < 63),
                                  N.logical_and(longitude > 157, longitude < 163))
    bool_okhot_12 = N.logical_and(N.logical_and(latitude > 60, latitude < 63),
                                  N.logical_and(longitude > 162, longitude < 164))
    bool_okhot_13 = N.logical_and(N.logical_and(latitude > 48, latitude < 51),
                                  N.logical_and(longitude > 151, longitude < 157))

    bool_okhot = bool_okhot_1
    for i in range(2, 14):
        exec ('bool_okhot=N.logical_or(bool_okhot,bool_okhot_' + str(i) + ')')

    okhotskx = N.where(bool_okhot, mask_v, 0)
    dom_dict['Okhotsk'] = okhotskx
    dom_arct['OKHOTSKX'] = okhotskx
    #
    # Bering Sea
    #
    bool_bering_1 = N.logical_and(N.logical_and(latitude > 58, latitude < 66), longitude < -154)
    bool_bering_2 = N.logical_and(N.logical_and(latitude > 55, latitude < 66), longitude > 161)
    bool_bering_3 = N.logical_and(N.logical_and(latitude > 53, latitude < 60), longitude > 160)
    bool_bering_4 = N.logical_and(N.logical_and(latitude > 56, latitude < 60), longitude < -155)
    bool_bering_5 = N.logical_and(N.logical_and(latitude > 55, latitude < 58),
                                  N.logical_or(longitude < -157, longitude > 163))
    bool_bering_6 = N.logical_and(N.logical_and(latitude > 54, latitude < 57),
                                  N.logical_or(longitude < -160, longitude > 167))
    bool_bering_7 = N.logical_and(N.logical_and(latitude > 54, latitude < 56),
                                  N.logical_or(longitude < -165, longitude > 171))
    bool_bering_8 = N.logical_and(N.logical_and(latitude > 53, latitude < 55),
                                  N.logical_or(longitude < -170, longitude > 174))
    bool_bering_9 = N.logical_and(N.logical_and(latitude > 53, latitude < 54),
                                  N.logical_or(longitude < -174, longitude > 177))
    bool_bering_10 = N.logical_and(N.logical_and(latitude > 52, latitude < 53), longitude < -178)
    #
    bool_bering = bool_bering_1
    for i in range(2, 11):  # 2,11
        exec ('bool_bering=N.logical_or(bool_bering,bool_bering_' + str(i) + ')')

    beringx = N.where(bool_bering, mask_v, 0)

    idx_5 = N.where((beringx == 1) & (okhotskx == 1))  # for removing the overlapping between the regions
    beringx[idx_5] = 0

    dom_dict['Bering'] = beringx
    dom_arct['BERINGXX'] = beringx
    #
    # Beaufort Sea (NW PASSAGE)
    #
    bool_beauf_1 = N.logical_and(N.logical_and(latitude > 75, latitude < 76),
                                 N.logical_and(longitude > -130, longitude < -124))
    bool_beauf_2 = N.logical_and(N.logical_and(latitude > 74, latitude < 75),
                                 N.logical_and(longitude > -136, longitude < -124))
    bool_beauf_3 = N.logical_and(N.logical_and(latitude > 73, latitude < 74),
                                 N.logical_and(longitude > -143, longitude < -125))
    bool_beauf_4 = N.logical_and(N.logical_and(latitude > 72, latitude < 73),
                                 N.logical_and(longitude > -149, longitude < -125))
    bool_beauf_5 = N.logical_and(N.logical_and(latitude > 71, latitude < 72),
                                 N.logical_and(longitude > -156, longitude < -126))
    bool_beauf_6 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                 N.logical_and(longitude > -156, longitude < -126))
    bool_beauf_7 = N.logical_and(N.logical_and(latitude > 69, latitude < 70),
                                 N.logical_and(longitude > -156, longitude < -127))
    bool_beauf_8 = N.logical_and(N.logical_and(latitude > 73, latitude < 77),
                                 N.logical_and(longitude > -124, longitude < -120))
    bool_beauf_9 = N.logical_and(N.logical_and(latitude > 73, latitude < 75),
                                 N.logical_and(longitude > -125, longitude < -124))
    bool_beauf_10 = N.logical_and(N.logical_and(latitude > 69, latitude < 73),
                                  N.logical_and(longitude > -127, longitude < -124))
    bool_beauf = bool_beauf_1
    for i in range(2, 11):
        exec ('bool_beauf=N.logical_or(bool_beauf,bool_beauf_' + str(i) + ')')

    beaufort = N.where(bool_beauf, mask_v, 0)
    dom_dict['Beaufort_Sea'] = beaufort
    dom_arct['BEAUFORT'] = beaufort
    #
    #
    # Baffin Bay (including Kennedy Passage and Davis Strait)
    #
    bool_baff_1 = N.logical_and(N.logical_and(latitude > 70, latitude < 81),
                                N.logical_and(longitude > -84, longitude < -45))
    # Now, it is the official definition of Davis Strait...

    bool_baff_2 = N.logical_and(N.logical_and(latitude > 66, latitude < 70),
                                N.logical_and(longitude > -70, longitude < -45))  # longitude>-70, longitude <-45
    bool_baff_3 = N.logical_and(N.logical_and(latitude > 62, latitude < 66),
                                N.logical_and(longitude > -66, longitude < -45))  # longitude>-66, longitude <-45
    bool_baff_4 = N.logical_and(N.logical_and(latitude > 61, latitude < 62),
                                N.logical_and(longitude > -65, longitude < -45))  # longitude>-65, longitude <-45

    bool_baff = bool_baff_1
    for i in range(2, 5):
        exec ('bool_baff=N.logical_or(bool_baff,bool_baff_' + str(i) + ')')

    baffinxx = N.where(bool_baff, mask_v, 0)
    dom_dict['Baffin_Bay'] = baffinxx
    dom_arct['BAFFINXX'] = baffinxx
    #
    #
    # Hudson Bay (including Hudson Strait and Foxe Basin)
    #
    bool_huds_1 = N.logical_and(N.logical_and(latitude > 50, latitude < 67),
                                N.logical_and(longitude > -95, longitude < -66))  # longitude>-95, longitude <-66
    bool_huds_2 = N.logical_and(N.logical_and(latitude > 67, latitude < 70),
                                N.logical_and(longitude > -85, longitude < -70))  # longitude>-85, longitude <-70
    bool_huds_3 = N.logical_and(N.logical_and(latitude > 59, latitude < 62),
                                N.logical_and(longitude > -66, longitude < -65))  # longitude>-66, longitude <-65
    bool_huds = bool_huds_1
    for i in range(2, 4):
        exec ('bool_huds=N.logical_or(bool_huds,bool_huds_' + str(i) + ')')

    hudsonxx = N.where(bool_huds, mask_v, 0)

    idx = N.where((baffinxx == 1) & (hudsonxx == 1))
    hudsonxx[idx] = 0

    dom_dict['Hudson'] = hudsonxx
    dom_arct['HUDSONXX'] = hudsonxx
    #
    #
    # Labrador Sea
    #
    bool_labr_1 = N.logical_and(N.logical_and(latitude > 60, latitude < 61),
                                N.logical_and(longitude > -65, longitude < -45))
    bool_labr_2 = N.logical_and(N.logical_and(latitude > 59, latitude < 60),
                                N.logical_and(longitude > -65, longitude < -46))
    bool_labr_3 = N.logical_and(N.logical_and(latitude > 58, latitude < 59),
                                N.logical_and(longitude > -64, longitude < -46))
    bool_labr_4 = N.logical_and(N.logical_and(latitude > 57, latitude < 58),
                                N.logical_and(longitude > -63, longitude < -47))
    bool_labr_5 = N.logical_and(N.logical_and(latitude > 56, latitude < 57),
                                N.logical_and(longitude > -62, longitude < -47))
    bool_labr_6 = N.logical_and(N.logical_and(latitude > 55, latitude < 56),
                                N.logical_and(longitude > -61, longitude < -48))
    bool_labr_7 = N.logical_and(N.logical_and(latitude > 54, latitude < 55),
                                N.logical_and(longitude > -60, longitude < -48))
    bool_labr_8 = N.logical_and(N.logical_and(latitude > 53, latitude < 54),
                                N.logical_and(longitude > -59, longitude < -49))
    bool_labr_9 = N.logical_and(N.logical_and(latitude > 51, latitude < 53),
                                N.logical_and(longitude > -58, longitude < -49))
    bool_labr_10 = N.logical_and(N.logical_and(latitude > 48.5, latitude < 52),
                                 N.logical_and(longitude > -57, longitude < -50))
    bool_labr_11 = N.logical_and(N.logical_and(latitude > 50, latitude < 51),
                                 N.logical_and(longitude > -56, longitude < -50))
    bool_labr_12 = N.logical_and(N.logical_and(latitude > 47.5, latitude < 50),
                                 N.logical_and(longitude > -56, longitude < -51))
    bool_labr = bool_labr_1
    for i in range(2, 13):
        exec ('bool_labr=N.logical_or(bool_labr,bool_labr_' + str(i) + ')')

    labrador = N.where(bool_labr, mask_v, 0)
    dom_dict['Labrador_Sea'] = labrador
    dom_arct['LABRADOR'] = labrador
    #
    # Irminger
    #
    bool_irmi_1 = N.logical_and(N.logical_and(latitude > 58.30, latitude < 67.5),
                                N.logical_and(longitude > -46, longitude < -40))
    bool_irmi_2 = N.logical_and(N.logical_and(latitude > 60, latitude < 67.5),
                                N.logical_and(longitude > -40, longitude < -35))
    bool_irmi_3 = N.logical_and(N.logical_and(latitude > 61, latitude < 68),
                                N.logical_and(longitude > -35, longitude < -23))
    bool_irmi = bool_irmi_1
    for i in range(2, 4):
        exec ('bool_irmi=N.logical_or(bool_irmi,bool_irmi_' + str(i) + ')')
    irminger = N.where(bool_irmi, mask_v, 0)

    idx2 = N.where((labrador == 1) & (irminger == 1))
    irminger[idx2] = 0

    idx3 = N.where((icelands == 1) & (irminger == 1))
    irminger[idx3] = 0

    dom_dict['Irminger_Sea'] = irminger
    #
    # Northwest Passage
    # Southern part (passage Amundsen + official passage)
    bool_nwpa_1 = N.logical_and(N.logical_and(latitude > 73, latitude < 77),
                                N.logical_and(longitude > -120, longitude < -84))
    bool_nwpa_2 = N.logical_and(N.logical_and(latitude > 67, latitude < 73),
                                N.logical_and(longitude > -124, longitude < -85))
    # Northern part (Sverdrup Basin)
    bool_nwpa_3 = N.logical_and(N.logical_and(latitude > 76, latitude < 77),
                                N.logical_and(longitude > -120, longitude < -84))
    bool_nwpa_4 = N.logical_and(N.logical_and(latitude > 77, latitude < 78),
                                N.logical_and(longitude > -116, longitude < -84))
    bool_nwpa_5 = N.logical_and(N.logical_and(latitude > 78, latitude < 79),
                                N.logical_and(longitude > -108, longitude < -84))
    bool_nwpa_6 = N.logical_and(N.logical_and(latitude > 79, latitude < 80),
                                N.logical_and(longitude > -100, longitude < -84))
    bool_nwpa_7 = N.logical_and(N.logical_and(latitude > 80, latitude < 81),
                                N.logical_and(longitude > -93, longitude < -84))
    bool_nwpa_8 = N.logical_and(N.logical_and(latitude > 81, latitude < 82),
                                N.logical_and(longitude > -85, longitude < -84))
    bool_nwpa_9 = N.logical_and(N.logical_and(latitude > 82, latitude < 83),
                                N.logical_and(longitude > -77, longitude < -75))
    # I reached Cape Columbia (Ellesmere Island)
    bool_nwpa = bool_nwpa_1
    for i in range(2, 10):
        exec ('bool_nwpa=N.logical_or(bool_nwpa,bool_nwpa_' + str(i) + ')')

    nwestpas = N.where(bool_nwpa, mask_v, 0)
    dom_dict['NorthWest_Passage'] = nwestpas
    dom_dict['CanArch'] = nwestpas
    dom_arct['NWESTPAS'] = nwestpas
    # x.clear()
    # x.plot(nhemisph + 2*hudsonxx+2*baffinxx + 2*labrador + 2*beaufort + nwestpas)
    #
    #
    # Lincoln Sea
    bool_linc_1 = N.logical_and(N.logical_and(latitude > 81, latitude < 84),
                                N.logical_and(longitude > -60, longitude < -32))
    bool_linc_2 = N.logical_and(N.logical_and(latitude > 81, latitude < 83),
                                N.logical_and(longitude > -70, longitude < -60))
    bool_linc = N.logical_or(bool_linc_1, bool_linc_2)

    lincolnx = N.where(bool_linc, mask_v, 0)
    dom_dict['Lincoln_Sea'] = lincolnx
    dom_arct['LINCOLNX'] = lincolnx
    #
    #
    # Irminger Sea
    # Marginal seas
    dict_marg = ['GINSEASX', 'BARENTSX', 'KARAXXXX', 'BAFFINXX', 'LAPTEVXX', 'HUDSONXX', 'EASTSIBE', 'BEAUFORT',
                 'NWESTPAS', 'CHUKCHIS', 'BERINGXX', 'OKHOTSKX']
    dict_marg = ['Nordic_Seas', 'Barents_Sea', 'Kara_Sea', 'Baffin_Bay', 'Laptev_Sea', 'Hudson', 'East_Siberian_Sea',
                 'Beaufort_Sea', 'NorthWest_Passage', 'Chukchi_Sea', 'Bering', 'Okhotsk']
    marg = mask_v
    for sea in dict_marg:
        marg = marg + dom_dict[sea]
    bool_marg = marg > 1
    dom_dict['Arctic_Marginal_seas'] = N.where(bool_marg, mask_v, 0)
    dom_arct['MIZSEASX'] = N.where(bool_marg, mask_v, 0)

    # Central Arctic
    bool_centrarc = N.equal(marg, nhemisph)
    bool_centrarc = N.logical_and(bool_centrarc, latitude > 70)
    bool_centrarc = N.logical_and(bool_centrarc, N.logical_not(bool_linc))
    centrarc = N.where(bool_centrarc, mask_v, 0)
    dom_dict['Central_Arctic_1'] = centrarc
    dom_arct['CENTRARC'] = centrarc

    dom_dict['Central_Arctic'] = dom_dict['Central_Arctic_1'] + dom_dict['Lincoln_Sea']

    #
    # West Central Arctic
    bool_westcarc = N.logical_and(bool_centrarc, N.absolute(longitude) >= 90)
    wcentarc = N.where(bool_westcarc, mask_v, 0)
    dom_dict['Western_Central_Arctic'] = wcentarc
    #
    # East Central Arctic
    bool_eastcarc = N.logical_and(bool_centrarc, N.absolute(longitude) < 90)
    ecentarc = N.where(bool_eastcarc, mask_v, 0)
    dom_dict['Eastern_Central_Arctic'] = ecentarc
    #
    #
    #
    # Arctic Ocean
    #
    bool_arctic_1 = N.greater(marg, nhemisph)
    bool_arctic = N.logical_and(bool_arctic_1, latitude > 0)
    arcticoc = N.where(N.logical_or(bool_arctic, bool_centrarc), mask_v, 0)
    dom_dict['Arctic_Ocean'] = arcticoc
    #
    #
    # Baltic Sea
    # Gulfs of Bothnia, Riga, Finland.
    bool_balt_1 = N.logical_and(N.logical_and(latitude > 50, latitude < 66),
                                N.logical_and(longitude > 15, longitude < 30))
    # South of Sweden until Copenhaguen
    bool_balt_2 = N.logical_and(N.logical_and(latitude > 50, latitude < 56),
                                N.logical_and(longitude > 10, longitude < 15))
    bool_balt = bool_balt_1
    bool_balt = N.logical_or(bool_balt, bool_balt_2)
    baltseax = N.where(bool_balt, mask_v, 0)
    dom_dict['Baltic_Sea'] = baltseax
    dom_arct['BALTICXX'] = baltseax
    #
    #
    # Gulf of Saint-Lawrence
    bool_slaw = N.logical_and(N.logical_and(longitude > -70, longitude < -55),
                              N.logical_and(latitude < 52, latitude > 48))
    bool_slaw = N.logical_or(bool_slaw, N.logical_and(N.logical_and(longitude > -70, longitude < -58),
                                                      N.logical_and(latitude <= 48, latitude > 47)))
    bool_slaw = N.logical_or(bool_slaw, N.logical_and(N.logical_and(longitude > -70, longitude < -59),
                                                      N.logical_and(latitude <= 47, latitude > 46)))
    bool_slaw = N.logical_or(bool_slaw, N.logical_and(N.logical_and(longitude > -70, longitude < -60),
                                                      N.logical_and(latitude <= 46, latitude > 45)))
    bool_slaw = N.logical_and(bool_slaw, N.logical_not(bool_labr))
    slawrglf = N.where(bool_slaw, mask_v, 0)
    dom_dict['StLawr'] = slawrglf
    dom_arct['SLAWRGLF'] = slawrglf

    #
    #
    # Caspian Sea
    bool_casp = N.logical_and(N.logical_and(latitude > 35, latitude < 50),
                              N.logical_and(longitude > 45, longitude < 60))
    caspianx = N.where(bool_casp, mask_v, 0)
    dom_dict['Caspian_Sea'] = caspianx
    #
    #
    # Northern Hemisphere oceanic seas
    nhemisptot = nhemisph + caspianx + baltseax
    bool_nohemi = N.equal(nhemisptot, nhemisph)
    nnhemisp = N.where(bool_nohemi, nhemisph, 0)
    dom_dict['North_Hemisphere_Ocean'] = nnhemisp
    #
    # MAIN STRAITS
    #
    # Fram Strait (Northernmost Greenland Sea)
    bool_fram = N.logical_and(N.logical_and(latitude > 80, latitude < 81),
                              N.logical_and(longitude > -30, longitude < 17))
    fram = N.where(bool_fram, mask_v, 0)
    dom_dict['Fram_Strait'] = fram
    #
    #
    # Bering Strait (Southernmost Chukchi Sea: in Chk Sea)
    bool_bers = N.logical_and(N.logical_and(latitude > 65, latitude < 66),
                              N.logical_and(longitude > -175, longitude < -165))
    beringst = N.where(bool_bers, mask_v, 0)
    dom_dict['Bering_Strait'] = beringst
    #
    # Nares Strait (Northernmost Baffin Bay)
    bool_nares = N.logical_and(N.logical_and(latitude > 80, latitude < 81),
                               N.logical_and(longitude > -84, longitude < -45))
    narestr = N.where(bool_nares, mask_v, 0)
    dom_dict['Nares_Strait'] = narestr
    #
    #
    # Kara Gate Strait
    bool_kaga_1 = N.logical_and(N.logical_and(latitude > 70, latitude < 71),
                                N.logical_and(longitude > 57, longitude < 59))
    bool_kaga_2 = N.logical_and(N.logical_and(latitude > 69, latitude < 70),
                                N.logical_and(longitude > 60, longitude < 61))
    bool_kaga = bool_kaga_1
    bool_kaga = N.logical_or(bool_kaga, bool_kaga_2)
    karagstr = N.where(bool_kaga, mask_v, 0)
    dom_dict['Kara_Gate_Strait'] = karagstr
    #
    #
    # Vilkitsky Straitq
    bool_vilk_1 = N.logical_and(N.logical_and(latitude > 76, latitude <= 79),
                                N.logical_and(longitude > 100, longitude < 105))
    bool_vilk_2 = N.logical_and(N.logical_and(latitude > 70, latitude < 76),
                                N.logical_and(longitude > 99, longitude < 100))
    bool_vilk = bool_vilk_1
    bool_vilk = N.logical_or(bool_vilk, bool_vilk_2)
    vilkystr = N.where(bool_vilk, mask_v, 0)
    dom_dict['Vilkitsky_Strait'] = vilkystr
    #
    #
    # Simple boxes splitting the Antarctic Ocean...
    #
    # Weddell Sea
    #
    bool_weddll = N.logical_and(latitude < -40, N.logical_and(longitude > -65, longitude < -15))
    weddellx = N.where(bool_weddll, mask_v, 0)
    dom_dict['Weddell_Sea'] = weddellx
    #
    #
    # Ross Sea
    #
    bool_ross_1 = N.logical_and(latitude < -40, longitude < -140)
    bool_ross_2 = N.logical_and(latitude < -40, longitude > 160)
    bool_ross = N.logical_or(bool_ross_1, bool_ross_2)
    rossxxxx = N.where(bool_ross, mask_v, 0)
    dom_dict['Ross_Sea'] = rossxxxx
    #
    #
    # Amundsen Sea
    #
    bool_amund = N.logical_and(latitude < -40, N.logical_and(longitude > -140, longitude < -90))
    amundsen = N.where(bool_amund, mask_v, 0)
    dom_dict['Amundsen_Sea'] = amundsen
    #
    #
    # Bellingshausen Sea
    #
    bool_bellings = N.logical_and(latitude < -40, N.logical_and(longitude > -90, longitude < -65))
    bellings = N.where(bool_bellings, mask_v, 0)
    dom_dict['Bellingshausen_Sea'] = bellings
    #
    #
    # Atlantic-Antarctic
    #
    bool_atlantxx_1 = N.logical_and(latitude < -40, longitude > -15)
    bool_atlantxx_2 = N.logical_and(latitude < -40, longitude < 22)
    bool_atlantxx = N.logical_and(bool_atlantxx_1, bool_atlantxx_2)
    atlantxx = N.where(bool_atlantxx, mask_v, 0)
    dom_dict['Antarctic_Atlantic_Sector'] = atlantxx
    #
    #
    # Indian-Antarctic
    #
    bool_indiant = N.logical_and(latitude < -40, N.logical_and(longitude > 22, longitude < 160))
    indiantx = N.where(bool_indiant, mask_v, 0)
    dom_dict['Antarctic_Indian_Sector'] = indiantx
    #
    #
    # Other domains: lat
    lat80n = N.where(latitude > 80., mask_v, 0.)
    dom_dict['LAT80N'] = lat80n
    #
    #
    # Arctic Rings (Neven wants it like that --> 8 + 1 central)
    bool_ArcRing_1 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > 0, longitude < 45))
    CntArcticRing1 = N.where(bool_ArcRing_1, mask_v, 0)
    dom_dict['CntArcticRing1'] = CntArcticRing1
    #
    bool_ArcRing_2 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > 45, longitude < 90))
    CntArcticRing2 = N.where(bool_ArcRing_2, mask_v, 0)
    dom_dict['CntArcticRing2'] = CntArcticRing2
    #
    bool_ArcRing_3 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > 90, longitude < 135))
    CntArcticRing3 = N.where(bool_ArcRing_3, mask_v, 0)
    dom_dict['CntArcticRing3'] = CntArcticRing3
    #
    bool_ArcRing_4 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > 135, longitude < 180))
    CntArcticRing4 = N.where(bool_ArcRing_4, mask_v, 0)
    dom_dict['CntArcticRing4'] = CntArcticRing4
    #
    bool_ArcRing_5 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > -180, longitude < -135))
    CntArcticRing5 = N.where(bool_ArcRing_5, mask_v, 0)
    dom_dict['CntArcticRing5'] = CntArcticRing5
    #
    bool_ArcRing_6 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > -135, longitude < -90))
    CntArcticRing6 = N.where(bool_ArcRing_6, mask_v, 0)
    dom_dict['CntArcticRing6'] = CntArcticRing6
    #
    bool_ArcRing_7 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > -90, longitude < -45))
    CntArcticRing7 = N.where(bool_ArcRing_7, mask_v, 0)
    dom_dict['CntArcticRing7'] = CntArcticRing7
    #
    bool_ArcRing_8 = N.logical_and(N.logical_and(latitude < 86, latitude > 78),
                                   N.logical_and(longitude > -45, longitude < 0))
    CntArcticRing8 = N.where(bool_ArcRing_8, mask_v, 0)
    dom_dict['CntArcticRing8'] = CntArcticRing8
    #
    bool_ArcRing = N.logical_and(N.logical_and(latitude < 90, latitude > 86),
                                 N.logical_and(longitude > -180, longitude < 180))
    CntArctic = N.where(bool_ArcRing, mask_v, 0)
    dom_dict['CntArctic'] = CntArctic
    #
    # FOR OTHER BASINS: use subbasins.nc --> ONLY FOR ORCA1 CONFIGURATIONS !!!!!!!!
    #
    fsubname='subbasins.nc'
    fsub=nc(fsubname)
    # Atlantic Ocean
    #
    matl=fsub.variables['atlmsk'][:].squeeze()
    dom_dict['Atlantic_Ocean']=matl
    # Pacific Ocean
    mpac=fsub.variables['pacmsk'][:].squeeze()
    dom_dict['Pacific_Ocean']=mpac
    # Indian Ocean
    mind=fsub.variables['indmsk'][:].squeeze()
    dom_dict['Indian_Ocean']=mind
    #
    fsub.close()    
    #
    # COMBINATION OF REGIONS
    #
    # Barents + Kara Seas
    #
    dom_dict['BarKara'] = dom_dict['Barents_Sea'] + dom_dict['Kara_Sea']
    #
    # East Sib + Laptev Seas
    #
    dom_dict['Laptev-East_Siberian_Seas'] = dom_dict['East_Siberian_Sea'] + dom_dict['Laptev_Sea']
    #
    # Canadian Archipelago
    #
    dom_dict['Canadian_Waters'] = dom_dict['NorthWest_Passage'] + dom_dict['Baffin_Bay'] + dom_dict['Hudson'] + \
                                  dom_dict['Labrador_Sea']
    #
    # Beaufort + Chukchi Seas
    #
    dom_dict['Beaufort-Chukchi_Sea'] = dom_dict['Beaufort_Sea'] + dom_dict['Chukchi_Sea']
    #
    # East Sib + Laptev + Chukchi Seas
    #
    dom_dict['Laptev-East_Siberian-Chukchi_Seas'] = dom_dict['Laptev-East_Siberian_Seas'] + dom_dict['Chukchi_Sea']
    #
    # GIN + Barents Seas
    #
    dom_dict['Nordic-Barents_Seas'] = dom_dict['Nordic_Seas'] + dom_dict['Barents_Sea']
    #
    # Mask Serreze
    boolarcticxx = dom_dict['Central_Arctic'] + dom_dict['Barents_Sea'] + \
                   dom_dict['Kara_Sea'] + dom_dict['Laptev_Sea'] + \
                   dom_dict['East_Siberian_Sea'] + dom_dict['Chukchi_Sea'] + \
                   dom_dict['Beaufort_Sea']

    boolamundsen = N.logical_and(nwestpas, longitude < -113.)
    dom_dict['Serreze_Arctic'] = boolarcticxx + boolamundsen
    #
    # =======================
    # COMBINATION FOR COMPARING AGAINST THE NSIDC

    nsbaffin = baffinxx + labrador
    dom_dict['Baffin'] = nsbaffin
    nsarcton = centrarc + lincolnx + chukchis + eastsibe + laptevxx + beaufort
    dom_dict['ArctOcn'] = nsarcton
    openocen = nnhemisp - arcticoc - labrador - slawrglf + baltseax
    dom_dict['OpenOcean'] = openocen
    #
    total_arc = baffinxx + barentsx + beaufort + beringx + nwestpas + \
                centrarc + chukchis + eastsibe + greenlan + hudsonxx + \
                icelands + karaxxxx + labrador + laptevxx + norskhav + okhotskx + lincolnx

    dom_dict['TotalArc'] = total_arc
    #
    # ======================================================
    # NEW MASKS (stage Marion)
    natlarc = northatl + dom_dict['Barents_Sea'] - dom_dict['Hudson'] - dom_dict['CanArch'] - dom_dict['Baltic_Sea']
    dom_dict['North_Atlantic-Arctic'] = N.where(natlarc >= 1., 1., 0.)
    #
    spgyre = natlarc - dom_dict['Baffin_Bay'] - dom_dict['Nordic-Barents_Seas']
    spgyre = N.where(latitude >= 70., 0., spgyre)
    dom_dict['Subpolar_Gyre'] = N.where(spgyre >= 1., 1., 0.)

    arcnatl = natlarc + nsarcton + dom_dict['Kara_Sea']
    dom_dict['Arctic_Ocean-North_Atlantic'] = N.where(arcnatl >= 1., 1., 0.)
    #
    fout = nc('mask.regions.%s.nc' % version, 'w')
    fout.createDimension('x', fmask.dimensions['x'].size)  # 1442
    fout.createDimension('y', fmask.dimensions['y'].size)  # 1021
    fout.createDimension('z', 3)
    fout.createDimension('t', None)

    i = 1
    dom_image = mask_v
    #############

    y_values = range(1, fmask.dimensions['y'].size + 1)  # 1022
    y = fout.createVariable('y', 'f', ('y'))
    y[:] = y_values
    y.axis = "Y"
    y.standard_name = "latitude"

    x_values = range(1, fmask.dimensions['x'].size + 1)  # 1443
    x = fout.createVariable('x', 'f', ('x'))
    x[:] = x_values
    x.axis = "X"
    x.standard_name = "longitude"

    z_values = range(1, 4)
    z = fout.createVariable('z', 'f', ('z'))
    z[:] = z_values
    z.axis = "Z"

    t_values = range(1, 2)
    t = fout.createVariable('t', 'f', ('t'))
    t[:] = t_values
    t.axis = "T"
    t.standard_name = "time"

    lat = fout.createVariable('nav_lat', 'f', ('t', 'z', 'y', 'x'))
    for z in range(0, 3):
        lat[0, z, :] = latitude

    lon = fout.createVariable('nav_lon', 'f', ('t', 'z', 'y', 'x'))
    for z in range(0, 3):
        lon[0, z, :] = longitude

    for dom in dom_dict:
        dom_var = fout.createVariable(dom, 'f', ('t', 'z', 'y', 'x'))
        for z in range(0, 3):
            dom_var[0, z, :] = dom_dict[dom]
        dom_var.long_name = dom
        dom_var.short_name = dom
        dom_var._name = dom
    fout.close()
    fmask.close()
